@@ -60,9 +60,9 @@ sub digest {
 
     my $digester = Digest::MD5->new;
 
-    my $attributes = $self->meta->get_attribute_map;
-    foreach my $aname (keys(%{ $attributes })) {
-        my $attr = $attributes->{$aname};
+    my @attributes = $self->meta->get_attribute_list;
+    foreach my $aname (@attributes) {
+        my $attr = $self->meta->get_attribute($aname);
 
         next unless $attr->does('Digest::SearchEngine::Meta::Attribute::Trait::Digestable');
 
@@ -80,6 +80,12 @@ sub digest {
     return $digester->b64digest;
 }
 
+sub has_filter_like {
+    my ($self, $predicate) = @_;
+
+    return grep { $predicate->() } $self->filter_names;
+}
+
 __PACKAGE__->meta->make_immutable;
 
 1;
@@ -150,6 +156,13 @@ Gets the value for the specified filter.
 
 Predicate that returns true if this query has filters.
 
+=head2 has_filter_like
+
+Returns true if any of the filter names match the provided subroutine:
+
+  $query->set_filter('foo', 'bar');
+  $query->has_filter_like(sub { /^fo/ })s; # true!
+
 =head2 set_filter
 
 Sets the value for the specified filter.
